aboutsummaryrefslogtreecommitdiffstats
path: root/home/print_text.asm
diff options
context:
space:
mode:
Diffstat (limited to 'home/print_text.asm')
-rw-r--r--home/print_text.asm10
1 files changed, 5 insertions, 5 deletions
diff --git a/home/print_text.asm b/home/print_text.asm
index 962ae519..65d418a3 100644
--- a/home/print_text.asm
+++ b/home/print_text.asm
@@ -1,18 +1,18 @@
; This function is used to wait a short period after printing a letter to the
; screen unless the player presses the A/B button or the delay is turned off
; through the [wd730] or [wLetterPrintingDelayFlags] flags.
PrintLetterDelay::
- ld a, [wd730]
- bit 6, a
+ ld a, [wStatusFlags5]
+ bit BIT_NO_TEXT_DELAY, a
ret nz
ld a, [wLetterPrintingDelayFlags]
- bit 1, a
+ bit BIT_TEXT_DELAY, a
ret z
push hl
push de
push bc
ld a, [wLetterPrintingDelayFlags]
- bit 0, a
+ bit BIT_FAST_TEXT_DELAY, a
jr z, .waitOneFrame
ld a, [wOptions]
and $f
@@ -1,18 +1,18 @@
; This function is used to wait a short period after printing a letter to the
; screen unless the player presses the A/B button or the delay is turned off
-; through the [wd730] or [wLetterPrintingDelayFlags] flags.
+; through the [wStatusFlags5] or [wLetterPrintingDelayFlags] flags.
PrintLetterDelay::